summaryrefslogtreecommitdiff
path: root/lisp/mail/feedmail.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/mail/feedmail.el')
-rw-r--r--lisp/mail/feedmail.el8
1 files changed, 4 insertions, 4 deletions
diff --git a/lisp/mail/feedmail.el b/lisp/mail/feedmail.el
index 2b63343239b..ff178241a90 100644
--- a/lisp/mail/feedmail.el
+++ b/lisp/mail/feedmail.el
@@ -561,7 +561,7 @@ but common in some proprietary systems."
;; maybe some distant mail system needs it. Really, though, if you
;; want a sender line in your mail, just put one in there and don't
;; wait for feedmail to do it for you. (Yes, I know all about
;; RFC-822 and RFC-1123, but are you *really* one of those cases
;; they're talking about? I doubt it.)
(defcustom feedmail-sender-line nil
"If non-nil and the email has no Sender: header, use this value.
@@ -787,7 +787,7 @@ cases the name element of the fiddle-plex is ignored and is hardwired
by feedmail to either \"Date\" or \"Resent-Date\".
If you decide to format your own date field, do us all a favor and know
-what you're doing. Study the relevant parts of RFC-822 and RFC-1123.
+what you're doing. Study the relevant parts of RFC-822-or-later and RFC-1123.
Don't make me come up there!
You should let feedmail generate a Date: for you unless you are sure
@@ -1514,7 +1514,7 @@ function, for example, to archive all of your sent messages someplace
(defvar feedmail-is-a-resend nil
- "Non-nil means the message is a Resend (in the RFC-822 sense).
+ "Non-nil means the message is a Resend (in the RFC-822-or-later sense).
This affects the composition of certain headers. feedmail sets this
variable as soon as it starts prepping the message text buffer, so any
user-supplied functions can rely on it. Users shouldn't set or change this
@@ -2443,7 +2443,7 @@ mapped to mostly alphanumerics for safety."
(let ((case-fold-search t) (addr-regexp))
(goto-char (point-min))
;; There are some RFC-822 combinations/cases missed here,
;; but probably good enough and what users expect.
;;
;; Use resent-* stuff only if there is at least one non-empty one.
@@ -561,7 +561,7 @@ but common in some proprietary systems."
;; want a sender line in your mail, just put one in there and don't
;; wait for feedmail to do it for you. (Yes, I know all about
-;; RFC-822 and RFC-1123, but are you *really* one of those cases
+;; RFC-822-or-later and RFC-1123, but are you *really* one of those cases
;; they're talking about? I doubt it.)
(defcustom feedmail-sender-line nil
@@ -2443,7 +2443,7 @@ mapped to mostly alphanumerics for safety."
(let ((case-fold-search t) (addr-regexp))
(goto-char (point-min))
- ;; There are some RFC-822 combinations/cases missed here,
+ ;; There are some RFC-822-or-later combinations/cases missed here,
;; but probably good enough and what users expect.
;;